@@ -1,21 +1,21 @@
 package Config::MVP::Section;
 # ABSTRACT: one section of an MVP configuration sequence
-$Config::MVP::Section::VERSION = '2.200007';
+$Config::MVP::Section::VERSION = '2.200009';
 use Moose 0.91;
 
 use Class::Load 0.17 ();
 use Config::MVP::Error;
 
-# =head1 DESCRIPTION
-#
-# For the most part, you can just consult L<Config::MVP> to understand what this
-# class is and how it's used.
-#
-# =attr name
-#
-# This is the section's name.  It's a string, and it must be provided.
-#
-# =cut
+#pod =head1 DESCRIPTION
+#pod
+#pod For the most part, you can just consult L<Config::MVP> to understand what this
+#pod class is and how it's used.
+#pod
+#pod =attr name
+#pod
+#pod This is the section's name.  It's a string, and it must be provided.
+#pod
+#pod =cut
 
 has name => (
   is  => 'ro',
@@ -23,13 +23,13 @@ has name => (
   required => 1
 );
 
-# =attr package
-#
-# This is the (Perl) package with which the section is associated.  It is
-# optional.  When the section is instantiated, it will ensure that this package
-# is loaded.
-#
-# =cut
+#pod =attr package
+#pod
+#pod This is the (Perl) package with which the section is associated.  It is
+#pod optional.  When the section is instantiated, it will ensure that this package
+#pod is loaded.
+#pod
+#pod =cut
 
 has package => (
   is  => 'ro',
@@ -38,19 +38,19 @@ has package => (
   predicate => 'has_package',
 );
 
-# =attr multivalue_args
-#
-# This attribute is an arrayref of value names that should be considered
-# multivalue properties in the section.  When added to the section, they will
-# always be wrapped in an arrayref, and they may be added to the section more
-# than once.
-#
-# If this attribute is not given during construction, it will default to the
-# result of calling section's package's C<mvp_multivalue_args> method.  If the
-# section has no associated package or if the package doesn't provide that
-# method, it default to an empty arrayref.
-#
-# =cut
+#pod =attr multivalue_args
+#pod
+#pod This attribute is an arrayref of value names that should be considered
+#pod multivalue properties in the section.  When added to the section, they will
+#pod always be wrapped in an arrayref, and they may be added to the section more
+#pod than once.
+#pod
+#pod If this attribute is not given during construction, it will default to the
+#pod result of calling section's package's C<mvp_multivalue_args> method.  If the
+#pod section has no associated package or if the package doesn't provide that
+#pod method, it default to an empty arrayref.
+#pod
+#pod =cut
 
 has multivalue_args => (
   is   => 'ro',
@@ -66,25 +66,25 @@ has multivalue_args => (
   },
 );
 
-# =attr aliases
-#
-# This attribute is a hashref of name remappings.  For example, if it contains
-# this hashref:
-#
-#   {
-#     file => 'files',
-#     path => 'files',
-#   }
-#
-# Then attempting to set either the "file" or "path" setting for the section
-# would actually set the "files" setting.
-#
-# If this attribute is not given during construction, it will default to the
-# result of calling section's package's C<mvp_aliases> method.  If the
-# section has no associated package or if the package doesn't provide that
-# method, it default to an empty hashref.
-#
-# =cut
+#pod =attr aliases
+#pod
+#pod This attribute is a hashref of name remappings.  For example, if it contains
+#pod this hashref:
+#pod
+#pod   {
+#pod     file => 'files',
+#pod     path => 'files',
+#pod   }
+#pod
+#pod Then attempting to set either the "file" or "path" setting for the section
+#pod would actually set the "files" setting.
+#pod
+#pod If this attribute is not given during construction, it will default to the
+#pod result of calling section's package's C<mvp_aliases> method.  If the
+#pod section has no associated package or if the package doesn't provide that
+#pod method, it default to an empty hashref.
+#pod
+#pod =cut
 
 has aliases => (
   is   => 'ro',
@@ -99,13 +99,13 @@ has aliases => (
   },
 );
 
-# =attr payload
-#
-# This is the storage into which properties are set.  It is a hashref of names
-# and values.  You should probably not alter the contents of the payload, and
-# should read its contents only.
-#
-# =cut
+#pod =attr payload
+#pod
+#pod This is the storage into which properties are set.  It is a hashref of names
+#pod and values.  You should probably not alter the contents of the payload, and
+#pod should read its contents only.
+#pod
+#pod =cut
 
 has payload => (
   is  => 'ro',
@@ -114,13 +114,13 @@ has payload => (
   default  => sub { {} },
 );
 
-# =attr is_finalized
-#
-# This attribute is true if the section has been marked finalized, which will
-# prevent any new values from being added to it.  It can be set with the
-# C<finalize> method.
-#
-# =cut
+#pod =attr is_finalized
+#pod
+#pod This attribute is true if the section has been marked finalized, which will
+#pod prevent any new values from being added to it.  It can be set with the
+#pod C<finalize> method.
+#pod
+#pod =cut
 
 has is_finalized => (
   is  => 'ro',
@@ -138,13 +138,13 @@ before finalize => sub {
     unless $self->sequence;
 };
 
-# =attr sequence
-#
-# This attributes points to the sequence into which the section has been
-# assembled.  It may be unset if the section has been created but not yet placed
-# in a sequence.
-#
-# =cut
+#pod =attr sequence
+#pod
+#pod This attributes points to the sequence into which the section has been
+#pod assembled.  It may be unset if the section has been created but not yet placed
+#pod in a sequence.
+#pod
+#pod =cut
 
 has sequence => (
   is  => 'ro',
@@ -176,18 +176,18 @@ sub sequence {
   return $seq;
 }
 
-# =method add_value
-#
-#   $section->add_value( $name => $value );
-#
-# This method sets the value for the named property to the given value.  If the
-# property is a multivalue property, the new value will be pushed onto the end of
-# an arrayref that will store all values for that property.
-#
-# Attempting to add a value for a non-multivalue property whose value was already
-# added will result in an exception.
-#
-# =cut
+#pod =method add_value
+#pod
+#pod   $section->add_value( $name => $value );
+#pod
+#pod This method sets the value for the named property to the given value.  If the
+#pod property is a multivalue property, the new value will be pushed onto the end of
+#pod an arrayref that will store all values for that property.
+#pod
+#pod Attempting to add a value for a non-multivalue property whose value was already
+#pod added will result in an exception.
+#pod
+#pod =cut
 
 sub add_value {
   my ($self, $name, $value) = @_;
@@ -214,35 +214,35 @@ sub add_value {
   $self->payload->{$name} = $value;
 }
 
-# =method load_package
-#
-#   $section->load_package($package, $plugin);
-#
-# This method is used to ensure that the given C<$package> is loaded, and is
-# called whenever a section with a package is created.  By default, it delegates
-# to L<Class::Load>.  If the package can't be found, it calls the
-# L<missing_package> method.  Errors in compilation are not suppressed.
-#
-# =cut
+#pod =method load_package
+#pod
+#pod   $section->load_package($package, $section_name);
+#pod
+#pod This method is used to ensure that the given C<$package> is loaded, and is
+#pod called whenever a section with a package is created.  By default, it delegates
+#pod to L<Class::Load>.  If the package can't be found, it calls the
+#pod L<missing_package> method.  Errors in compilation are not suppressed.
+#pod
+#pod =cut
 
 sub load_package {
-  my ($self, $package, $plugin) = @_;
+  my ($self, $package, $section_name) = @_;
 
   Class::Load::load_optional_class($package)
-    or $self->missing_package($package, $plugin);
+    or $self->missing_package($package, $section_name);
 }
 
-# =method missing_package
-#
-#   $section->missing_package($package, $plugin);
-#
-# This method is called when C<load_package> encounters a package that is not
-# installed.  By default, it throws an exception.
-#
-# =cut
+#pod =method missing_package
+#pod
+#pod   $section->missing_package($package, $section_name);
+#pod
+#pod This method is called when C<load_package> encounters a package that is not
+#pod installed.  By default, it throws an exception.
+#pod
+#pod =cut
 
 sub missing_package {
-  my ($self, $package, $plugin) = @_ ;
+  my ($self, $package, $section_name) = @_ ;
 
   my $class = Moose::Meta::Class->create_anon_class(
     superclasses => [ 'Config::MVP::Error' ],
@@ -252,13 +252,18 @@ sub missing_package {
         is       => 'ro',
         required => 1,
       )),
+      Moose::Meta::Attribute->new(section_name => (
+        is       => 'ro',
+        required => 1,
+      )),
     ],
   );
 
   $class->name->throw({
     ident   => 'package not installed',
-    message => "$package (for plugin $plugin) does not appear to be installed",
+    message => "$package (for section $section_name) does not appear to be installed",
     package => $package,
+    section_name => $section_name,
   });
 }
 
@@ -297,7 +302,7 @@ Config::MVP::Section - one section of an MVP configuration sequence
 
 =head1 VERSION
 
-version 2.200007
+version 2.200009
 
 =head1 DESCRIPTION
 
@@ -379,7 +384,7 @@ added will result in an exception.
 
 =head2 load_package
 
-  $section->load_package($package, $plugin);
+  $section->load_package($package, $section_name);
 
 This method is used to ensure that the given C<$package> is loaded, and is
 called whenever a section with a package is created.  By default, it delegates
@@ -388,7 +393,7 @@ L<missing_package> method.  Errors in compilation are not suppressed.
 
 =head2 missing_package
 
-  $section->missing_package($package, $plugin);
+  $section->missing_package($package, $section_name);
 
 This method is called when C<load_package> encounters a package that is not
 installed.  By default, it throws an exception.
@@ -399,7 +404,7 @@ Ricardo Signes <rjbs@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2014 by Ricardo Signes.
+This software is copyright (c) 2015 by Ricardo Signes.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
